@@ -181,7 +181,9 @@ fontCacheItem* getForContext(int contextId)
             // and the real effective fontRealName that libfontconfig actually gave us. Otherwise, as fontRealName
             // is returned to Screen(), we could get into a funny loop which causes false cache misses if the loaded font
             // doesn't match exactly the required one.
-            if ((fi->antiAliasing == _antiAliasing) && (fi->fontStyle == _fontStyle) && (fi->fontSize == _fontSize) &&
+            // NB: we ignore the third bit of fontStyle (4, underline) as that is not a font property but dealt with
+            // separately.
+            if ((fi->antiAliasing == _antiAliasing) && (fi->fontStyle == (_fontStyle & ~4)) && (fi->fontSize == _fontSize) &&
                 ((strcmp(fi->fontName, _fontName) == 0) || (strcmp(fi->fontRealName, _fontName) == 0)) &&
                 (fi->matrix.xx == _matrix.xx && fi->matrix.xy == _matrix.xy && fi->matrix.yx == _matrix.yx && fi->matrix.yy == _matrix.yy &&
                  fi->vector.x == _vector.x && fi->vector.y == _vector.y)) {
@@ -227,7 +229,7 @@ fontCacheItem* getForContext(int contextId)
     // Update tags:
     fi->contextId = contextId;
     fi->antiAliasing = _antiAliasing;
-    fi->fontStyle = _fontStyle;
+    fi->fontStyle = _fontStyle & ~4;    // ignore third bit (4, underline)
     fi->fontSize = _fontSize;
     strcpy(fi->fontName, _fontName);
     fi->matrix = _matrix;
@@ -510,10 +512,13 @@ void PsychGetTextCursor(int context, double* xp, double* yp, double* height)
 
     // Try to get line height of font:
     if (fi) {
-        if (fi->faceT)
-            *height = fi->faceT->height();
-        else
-            *height = fi->faceM->height();
+        // an OGLFT face's height() function uses the font height in the
+        // font's design units (perhaps a bug?). We need the font height
+        // scaled for the current character size display resolution.
+        // These are provided to FreeType during the FTGL face's
+        // constructor execution. We can directly access the scaled font
+        // info from the underlying FT_FACE.
+        *height = fi->ft_face->size->metrics.height / 64.;
     }
     else {
         *height = 0;
@@ -562,13 +567,18 @@ int PsychDrawText(int context, double xStart, double yStart, int textLen, double
     glPushAttrib(GL_ALL_ATTRIB_BITS);
     glPixelStorei( GL_UNPACK_ALIGNMENT, 1);
     glEnable( GL_TEXTURE_2D );
-    glTexEnvf( GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE );
+    glTexEnvf( GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE );
 
     glMatrixMode(GL_PROJECTION);
     glPushMatrix();
     glLoadIdentity();
-    gluOrtho2D(_vxs, _vxs + _vw, _vys, _vys + _vh);
+    gluOrtho2D(_vxs, _vxs + _vw, _vys + _vh, _vys);
     glMatrixMode(GL_MODELVIEW);
+    glPushMatrix();
+    // FTGL assumes bottom-left origin, our projection matrix has top-left origin: flip text vertically
+    glTranslated(0., yStart, 0.);
+    glScaled(1., -1., 1.);
+    glTranslated(0, -yStart, 0.);
 
     // Set text color: This will be filtered by OGLFT for redundant settings:
     if (fi->faceT) {
@@ -578,6 +588,14 @@ int PsychDrawText(int context, double xStart, double yStart, int textLen, double
         fi->faceM->setForegroundColor( _fgcolor[0], _fgcolor[1], _fgcolor[2], _fgcolor[3]);
     }
 
+    // Enable or disable underlining, depending on requested style:
+    if (fi->faceT) {
+        fi->faceT->setDoUnderLine(!!(_fontStyle & 4));
+    }
+    else if (fi->faceM) {
+        fi->faceM->setDoUnderLine(!!(_fontStyle & 4));
+    }
+
     // Rendering of background quad requested? -- True if background alpha > 0.
     if (_bgcolor[3] > 0) {
         // Yes. Compute bounding box of "to be drawn" text and render a quad in background color:
@@ -613,6 +631,7 @@ int PsychDrawText(int context, double xStart, double yStart, int textLen, double
     glMatrixMode(GL_PROJECTION);
     glPopMatrix();
     glMatrixMode(GL_MODELVIEW);
+    glPopMatrix();
     glDisable( GL_TEXTURE_2D );
     glPopAttrib();
     glPopClientAttrib();
@@ -640,6 +659,14 @@ int PsychMeasureText(int context, int textLen, double* text, float* xmin, float*
     QString uniCodeText = QString(myUniChars, textLen);
     delete [] myUniChars;
 
+    // Enable or disable underlining, depending on requested style:
+    if (fi->faceT) {
+        fi->faceT->setDoUnderLine(!!(_fontStyle & 4));
+    }
+    else if (fi->faceM) {
+        fi->faceM->setDoUnderLine(!!(_fontStyle & 4));
+    }
+
     // Compute its bounding box:
     glPushMatrix();
     OGLFT::BBox box = (fi->faceT) ? fi->faceT->measure(uniCodeText) : fi->faceM->measure(uniCodeText);
