@@ -715,12 +715,16 @@ static PsychArgFormatType PsychGetTypeFromMxPtr(const mxArray *mxPtr)
         format = PsychArgType_uint16;
     else if (mxIsUint32(mxPtr))
         format = PsychArgType_uint32;
+    else if (mxIsUint64(mxPtr))
+        format = PsychArgType_uint64;
     else if (mxIsInt8(mxPtr))
         format = PsychArgType_int8;
     else if (mxIsInt16(mxPtr))
         format = PsychArgType_int16;
     else if (mxIsInt32(mxPtr))
         format = PsychArgType_int32;
+    else if (mxIsInt64(mxPtr))
+        format = PsychArgType_int64;
     else if (mxIsDouble(mxPtr))
         format = PsychArgType_double;
     else if (mxIsSingle(mxPtr))
@@ -1873,11 +1877,15 @@ const char* PsychRuntimeGetPsychtoolboxRoot(psych_bool getConfigDir)
 
 /* PsychCopyInPointerArg() - Copy in a void* memory pointer which is
  * encoded as a 32 bit or 64 bit unsigned integer, depending if this
- * is a 32 bit or 64 bit build of Psychtoolbox.
+ * is a 32 bit or 64 bit build of Psychtoolbox. This also accepts uint64
+ * input on 32-Bit machines and uint32 input on 64-Bit machines, casting
+ * accordingly, or throwing a range error if trying to stuff true > 32 Bit
+ * input numbers into a 32-Bit pointer on a 32-Bit architecture.
  */
 psych_bool PsychCopyInPointerArg(int position, PsychArgRequirementType isRequired, void **ptr)
 {
     const mxArray     *mxPtr;
+    psych_uint64      tmp64;
     PsychError        matchError;
     psych_bool        acceptArg;
     psych_bool        is64Bit;
@@ -1886,15 +1894,25 @@ psych_bool PsychCopyInPointerArg(int position, PsychArgRequirementType isRequire
     is64Bit = sizeof(size_t) > 4;
 
     PsychSetReceivedArgDescriptor(position, FALSE, PsychArgIn);
-    PsychSetSpecifiedArgDescriptor(position, PsychArgIn, ((is64Bit) ? PsychArgType_uint64 : PsychArgType_uint32), isRequired, 1,1,1,1,1,1);
+    PsychSetSpecifiedArgDescriptor(position, PsychArgIn, PsychArgType_uint64 | PsychArgType_uint32, isRequired, 1,1,1,1,1,1);
     matchError=PsychMatchDescriptors();
 
     acceptArg=PsychAcceptInputArgumentDecider(isRequired, matchError);
     if (acceptArg) {
         mxPtr = PsychGetInArgMxPtr(position);
 
-        if (is64Bit) {
-            *ptr = (void*) (size_t) (((psych_uint64*) mxGetData(mxPtr))[0]);
+        if (PsychGetTypeFromMxPtr(mxPtr) == PsychArgType_uint64) {
+            tmp64 = ((psych_uint64*) mxGetData(mxPtr))[0];
+
+            // Range check if uint64 fits into a 32 bit pointer on this 32-Bit build?
+            // Should only happen on 32-Bit builds if routine is (ab)used on something
+            // else than a memory pointer for the machine architecture:
+            if (!is64Bit && (tmp64 > 0xffffffff)) {
+                printf("PTB-ERROR:PsychCopyInPointerArg(): %i th uint64 input argument does not fit into 32-Bit pointer!\n", position);
+                PsychErrorExitMsg(PsychError_user, "Out of range uint64 value passed for conversion into 32-Bit pointer.");
+            }
+
+            *ptr = (void*) (size_t) tmp64;
         } else {
             *ptr = (void*) (size_t) (((psych_uint32*) mxGetData(mxPtr))[0]);
         }
