@@ -42,7 +42,10 @@ static char synopsisString[] =
 "devices can't get auto-detected and are therefore not addressable this way. For such devices you "
 "must find out the type and unique identifier of the device. Then pass in a negative 'deviceIndex' "
 "to tell Screen you want to select a hidden device by its name or id, and pass in the name or id of "
-"that hidden device as string in the argument 'targetmoviename'. See 'help VideoCapture' for more info.\n"
+"that hidden device as string in the argument 'targetmoviename', or via the 'SetNextCaptureBinSpec=' "
+"option in Screen('SetVideoCaptureParameter'). The special deviceIndex -9 will create a new GStreamer "
+"videocapture bin out of a given gst-launch style 'SetNextCaptureBinSpec=' string and attach that as "
+"a video source. This allows to create arbitrary GStreamer video capture pipelines.\n"
 "'roirectangle' if specified, defines the requested size "
 "for captured images. The default is to return the maximum size image provided by the capture device. "
 "A 'roirectangle' setting of [0 0 width height] will not define a region of interest, but instead request a "
@@ -116,11 +119,11 @@ static char synopsisString[] =
 "'captureEngineType' This optional parameter allows selection of the video capture engine to use for this "
 "video source. Allowable values are currently 1 and 3. "
 "A value of 1 selects Firewire video capture via the free software library libdc1394-V2. "
-"That engine only supports high performance machine vision cameras that are compliant with the "
-"IIDC-1.x standard and are connected via a Firewire (IEEE-1394) bus system. Use of the engine with such "
-"cams allows for much higher flexibility and performance than use of video capture via GStreamer, however "
-"one restriction is that sound recording isn't yet supported with firewire capture. "
-"The firewire capture engine is supported on Linux and MacOS/X, but not on MS-Windows.\n\n"
+"That engine only supports high performance IIDC machine vision cameras that are compliant with the "
+"IIDC-1.x standard and are connected via a Firewire (IEEE-1394) bus system or via USB-3 USBVision standard. "
+"Use of the engine with such cams allows for much higher flexibility and performance than use of video capture "
+"via GStreamer, however one restriction is that sound recording isn't yet supported with this capture engine. "
+"This IIDC capture engine is supported on Linux and to a lesser degree on MacOSX, but not on MS-Windows.\n\n"
 "A value of 3 selects the GStreamer video capture engine. This engine is supported on all operating systems "
 "and allows for video and sound recording of captured video and audio streams. Type 'help GStreamer' for "
 "installation and setup instructions for the required GStreamer runtime libraries.\n\n"
@@ -137,7 +140,7 @@ static char synopsisString[] =
 "or 1 Byte resolution per luminance or color channel for classic 256 levels of intensity. Lower values are unsupported "
 "and will get rounded up to 8 bpc. Higher values may be supported by some higher end professional class cameras. If "
 "you ask for an unsupported value, the engine will try to get the lowest supported value that matches or exceeds "
-"what you want. Currently the firewire engine for pro-class IIDC compliant firewire or USB machine vision cameras "
+"what you want. Currently the libdc1394 engine for pro-class IIDC compliant firewire or USB machine vision cameras "
 "supports bitdepth > 8 bpc on capable cameras. The GStreamer engine always supports 8 bpc and it may support 16 bpc on "
 "capable cameras. Please note that requesting > 8 bpc will cause a substantial increase in both video bus "
 "bandwidth and memory consumption: Twice the bus bandwidth and two to four times the amount of memory per video frame, "
