@@ -133,7 +133,7 @@ else
             PsychHID('KbQueueStart');
         end
         
-        if (IsOSX(1) || (IsOctave && IsGUI))
+        if IsOctave && IsGUI
             % Enable keystroke redirection via kbqueue and pty to bypass
             % blockade of onscreen windows:
             PsychHID('KeyboardHelper', -14);
