@@ -70,7 +70,7 @@ if answer == 'd'
     BitsPlusPlus('SetTargetDeviceType', 1);
 else
     % Tell BitsPlusPlus driver that this is operating on a Bits+ or Bits# :
-    BitsPlusPlus('SetTargetDeviceType', 0);    
+    BitsPlusPlus('SetTargetDeviceType', 0);
 end
 
 % If it is a Bits#, open a connection to it:
@@ -82,15 +82,6 @@ if answer == 's'
     BitsPlusPlus('OpenBits#', bitsSharpPortName);
 end
 
-% Device specific low-level diagnostics to be run?
-if (answer == 'd') || (answer == 's') 
-    answer = input('Run external DataPixx/ViewPixx/ProPixx/Bits# device diagnostics as well [Time consuming]? [y/n] ', 's');
-    if answer == 'y'
-        % Enable one-shot diagnostic of GPU encoders via DataPixx et al. or Bits#:
-        BitsPlusPlus('TestGPUEncoders');
-    end
-end
-
 oldverbosity = Screen('Preference', 'Verbosity', 2);
 oldsynclevel = Screen('Preference', 'SkipSyncTests', 2);
 
@@ -154,7 +145,7 @@ Screen('HookFunction', window, 'Enable', 'FinalOutputFormattingBlit');
 
 % Draw Color++ image as generated by PTB GPU imaging pipeline:
 dstRect = Screen('Rect', hdrtexIndex);
-Screen('DrawTexture',window,hdrtexIndex, [], dstRect, [], 0);
+Screen('DrawTexture',window,hdrtexIndex, [], OffsetRect(dstRect, 1, 1), [], 0);
 
 % Finalize image before we take a screenshot:
 Screen('DrawingFinished', window, 0, 1);
@@ -166,13 +157,14 @@ spo = [ 0, -1, -1, -1,  0,  0, +1, +1, +1 ; ...
         0, -1,  0, +1, -1, +1, -1,  0, +1];
 
 fprintf('\n\n');
-    
+minerror = inf;
+
 for idx = 1:size(spo, 2)
     dx = spo(1, idx);
     dy = spo(2, idx);
     
     % Take screenshot of GPU converted image:
-    convImage=Screen('GetImage', window, OffsetRect(ScaleRect(dstRect, 2, 1), dx, dy),'backBuffer');
+    convImage=Screen('GetImage', window, OffsetRect(ScaleRect(dstRect, 2, 1), dx + 2, dy + 1),'backBuffer');
 
     % Compute difference images between Matlab converted packedImage and GPU converted
     % HDR image:
@@ -187,12 +179,6 @@ for idx = 1:size(spo, 2)
 
     fprintf('ReadbackOffset (%i, %i): Maximum raw data difference: red= %f green = %f blue = %f\n', dx, dy, mdr, mdg, mdb);
 
-    % Perfect results?
-    if ((mdr == 0) && (mdg == 0) && (mdb == 0))
-        % Yep. Done!
-        break;
-    end
-
     % If there is a difference, show plotted difference if requested:
     if (mdr>0 || mdg>0 || mdb>0) && plotdiffs
         % Differences detected!
@@ -255,11 +241,18 @@ for idx = 1:size(spo, 2)
         % No error: Set maxdiff to zero.
         maxdiff = 0;
     end
-    
+
     % Compute absolute effective maximum error in color intensity over all
     % values, pixels and channels. This is the true "human visible" error.
     maxerror = max(maxdiff);
-    
+
+    % Track minimum error and the settings that lead to it:
+    if maxerror < minerror
+        minerror = maxerror;
+        mindx = dx;
+        mindy = dy;
+    end
+
     % Error small enough to be acceptable for practical purposes?
     if maxerror <= acceptableerror
         % Yes. Skip further tests at different rasterizer offsets:
@@ -267,6 +260,10 @@ for idx = 1:size(spo, 2)
     end
 end
 
+% Move ahead with the dx,dy offsets that gave the best results:
+dx = mindx;
+dy = mindy;
+
 % Show GPU converted image. Should obviously not make any visual difference if
 % it is the same as the Matlab converted image.
 vbl = Screen('Flip', window);
@@ -277,7 +274,7 @@ Screen('HookFunction', window, 'Disable', 'FinalOutputFormattingBlit');
 % Build and draw texture from packed image:
 texpacked= Screen('MakeTexture', window, packedImage);
 dstRect = Screen('Rect', texpacked);
-Screen('DrawTexture', window, texpacked, [], dstRect, [], 0);
+Screen('DrawTexture', window, texpacked, [], OffsetRect(dstRect, 2, 1), [], 0);
 
 % Show it:
 vbl = Screen('Flip', window, vbl + 1);
@@ -304,6 +301,7 @@ if (mdr>0 || mdg>0 || mdb>0)
     else
         % Error too big to be acceptable.
         fprintf('The effective absolute maximal error of %f is bigger than the\nrejection threshold of %f units.\n', maxerror, acceptableerror);
+        fprintf('The best case absolute minimal error of %f is bigger than the\nrejection threshold of %f units.\n', minerror, acceptableerror);
         fprintf('This should not happen on properly and accurately working graphics hardware.\n');
         fprintf('Either there is a bug in the graphics driver, or something is misconfigured or\n');
         fprintf('your hardware is too old and not capable of performing the calculations in sufficient\n');
@@ -427,13 +425,13 @@ Screen('HookFunction', window, 'Enable', 'FinalOutputFormattingBlit');
 
 % Draw Mono++ image as generated by PTB GPU imaging pipeline:
 dstRect = Screen('Rect', hdrtexIndex);
-Screen('DrawTexture',window,hdrtexIndex, [], dstRect, [], 0);
+Screen('DrawTexture',window,hdrtexIndex, [], OffsetRect(dstRect, 1, 1), [], 0);
 
 % Finalize image before we take a screenshot:
 Screen('DrawingFinished', window, 0, 1);
 
 % Take screenshot of GPU converted image:
-convImage=Screen('GetImage', window, OffsetRect(dstRect, dx, dy), 'backBuffer');
+convImage=Screen('GetImage', window, OffsetRect(dstRect, dx + 1, dy + 1), 'backBuffer');
 
 % Show GPU converted image. Should obviously not make any visual difference if
 % it is the same as the Matlab converted image.
@@ -445,7 +443,7 @@ Screen('HookFunction', window, 'Disable', 'FinalOutputFormattingBlit');
 % Build and draw texture from packed image:
 texpacked= Screen('MakeTexture', window, packedImage);
 dstRect = Screen('Rect', texpacked);
-Screen('DrawTexture', window, texpacked, [], dstRect, [], 0);
+Screen('DrawTexture', window, texpacked, [], OffsetRect(dstRect, dx + 1, dy + 1), [], 0);
 
 % Keep it onscreen for 2 seconds, then blank screen:
 vbl = Screen('Flip', window, vbl + 2);
@@ -571,9 +569,8 @@ end
 
 fprintf('\n\n------------------- Mono++ test success! -------------------------------------\n\n');
 
-% All tests successful: Write this configuration to file as being
-% validated:
-BitsPlusPlus('StoreValidation', window);
+% All tests successful: Write this configuration to file as the imaging pipeline from usercode -> framebuffer being validated:
+BitsPlusPlus('StoreValidation', window, 1);
 
 % Done. Close everything down:
 BitsPlusPlus('ResetOnWindowClose');
@@ -581,6 +578,7 @@ Screen('CloseAll');
 RestoreCluts;
 
 fprintf('\n\nSUMMARY: BitsPlusPlus imaging pipeline verified to work correctly. Validation info stored.\n');
+fprintf('You may want to run BitsPlusIdentityClutTest next to test the path from framebuffer to output device.\n');
 
 % Done for now.
 return;
