@@ -38,12 +38,15 @@ function usedAnswers = PsychLinuxConfiguration(answers, dontshowad)
 % of the 'psychtoolbox' group to allow easy reconfiguration of
 % the X11 display system for running experiment sessions.
 %
+% Additionally it configures the gpu's to allow for display color
+% depths of more than 8 bpc. Furthermore, it configures a potentially
+% installed gamemoded daemon to further optimize cpu and graphics
+% performance for use with Psychtoolbox.
+%
 % The script calls into the shell via "sudo" to achieve this
 % setup task, which itself needs admin privileges to modify
 % system files etc. "sudo" will prompt the user for his admin
-% password to complete the tasks. This does not work on Octave
-% with GUI though. You will need octave --no-gui to execute this
-% script once if you use octave.
+% password to complete the tasks.
 %
 % The script also checks if any special configuration is required
 % to work around Linux specific OpenGL quirks of Matlab R2014b or
@@ -258,7 +261,15 @@ if ~exist('/etc/modprobe.d/amddeepcolor-psychtoolbox.conf', 'file') || ...
   fprintf('These files need to be installed if you want to use high color precision mode\n');
   fprintf('to drive a HDMI or DisplayPort high precision display device with more than\n');
   fprintf('8 bpc color depths, ie. more than 256 levels of red, green and blue color.\n');
-  fprintf('You do not need to install it for pure 8 bpc mode.\n');
+  if IsARM
+    % Some special treatment crammed in here for the latest RPi OS 11 BS:
+    fprintf('\nYou also need this file on the RaspberryPi computer to get non-broken visual\n');
+    fprintf('stimulation timing with RaspberryPi OS 11, so i will install the file for you.\n');
+    answers(6) = 'y';
+  else
+    fprintf('You do not need to install it for pure 8 bpc mode.\n');
+  end
+
   if ismember(answers(6), 'yn')
     answer = answers(6);
   else
@@ -281,6 +292,11 @@ else
       needinstall = 3;
     end
 
+    if IsARM
+      % Force it for the RaspberryPi:
+      answers(6) = 'y';
+    end
+
     fprintf('However, they seem to be outdated. I have more recent versions with me.\n');
     if ismember(answers(6), 'yn')
       answer = answers(6);
